#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mighttpd2
version:              4.0.4
visibility:           public
id:                   mighttpd2-4.0.4-EuMmkl0gukU43ZQKy2PwOY
key:                  mighttpd2-4.0.4-EuMmkl0gukU43ZQKy2PwOY
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://kazu-yamamoto.github.io/mighttpd2/
synopsis:             High performance web server on WAI/warp
description:
    High performance web server to handle static
    files and CGI on WAI/warp.
    Reverse proxy functionality is also provided
    to connect web applications behind.

category:             Network, Web
abi:                  76132004ca0df5f9aa7f32cb9dc3672e
exposed:              True
exposed-modules:
    Program.Mighty Program.Mighty.ByteString Program.Mighty.Config
    Program.Mighty.Dhall.Option Program.Mighty.Network
    Program.Mighty.Parser Program.Mighty.Process Program.Mighty.Report
    Program.Mighty.Resource Program.Mighty.Route Program.Mighty.Signal
    Program.Mighty.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mighttpd2-4.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mighttpd2-4.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mighttpd2-4.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/mighttpd2
hs-libraries:         HSmighttpd2-4.0.4-EuMmkl0gukU43ZQKy2PwOY
depends:
    array-0.5.6.0 async-2.2.6-HVFcnXCzrULJJSPrXugzlh
    auto-update-0.1.6-DMlu9LigmlmKEpjKplWxWa base-4.18.2.1
    byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Jy8OxWsCrDaBhFbgZ9qrNJ
    conduit-1.3.6.1-2TgBnHtxRcL45MnFdbw3BB
    conduit-extra-1.3.8-IMQsosV8b6Ffbob12dcl9
    dhall-1.42.3-DRzp8Cw7KB5CC8LwxDhczL directory-1.3.8.5
    filepath-1.4.300.1 http-date-0.0.11-DIXrushX9L96bbvl3LyVVs
    http-types-0.12.4-DdbAmHNhx8C4vBT5NO2sZU
    network-3.1.4.0-5QGUGxzwH322yW8TioI43L parsec-3.1.16.1
    resourcet-1.2.6-1nkc80Rj0478ycxyUoAOs8
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    streaming-commons-0.2.3.1-17zpNWcota6C45Ep9hbeLA text-2.0.2
    unix-2.8.4.0 unix-time-0.4.17-BPRLd1UbC9PKdqYIUXFqRD
    unliftio-0.2.25.1-406ICvddDrs4REwMxxdvSj
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu
    wai-3.2.4-IVqPMwlk2Y5DK0IkF0sPx
    wai-app-file-cgi-3.1.11-HKF9rVz9DfMJFxzAhLOSyP
    warp-3.4.0-JUulTfZKBZC2vlkmUFi6Ft

haddock-interfaces:   /usr/share/doc/mighttpd2/html/mighttpd2.haddock
haddock-html:         /usr/share/doc/mighttpd2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

